==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/da.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Dokumenter",
"Can't create document" => "Kan ikke oprette dokument",
"You don't have permission to rename this document" => "Du har ikke tilladelse til at omdøbe dette dokument",
"Directory saved successfully." => "Mappen blev gemt.",
"An error occurred while changing directory." => "Fejl ved skift af bibliotek.",
"Saved" => "Gemt",
"Format filter server is down or misconfigured" => "Formatfilter-server er nede eller konfigureret forkert",
"Conversion failed. Check log for details." => "Konvertering mislykkedes. Tjek loggen for detaljer.",
"document-styles" => "dokument-stile",
"document-content" => "dokument-indhold",
"bold" => "fed",
"italic" => "kursiv",
"solid" => "solid",
"pt" => "pkt",
"Saving..." => "Gemmer...",
"Failed to load documents." => "Kunne ikke hente dokumenterne. ",
"No documents were found. Upload or create a document to get started!" => "Der blev ikke fundet nogle dokumenter. Upload eller opret et dokument for at komme igang",
"No connection to server. Trying to reconnect." => "Ingen forbindelse til servver. Prøv at forbinde igen.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "At forlade denne side i redigeringstilstand kan resultere i ikke gemte data. Det anbefales at bruge 'Luk' knappen i stedet.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Kunne ikke hentet dette dokument. Undersøg venligst om det kan åbnes med en ekstern odt læser. Dette kan også betyde at dokumentet for nylig er blevet gjort privat eller slettet. ",
"Save" => "Gem",
"Loading documents..." => "Henter dokumenter...",
"'.' is an invalid file name." => "'.' er et ugyldigt filnavn.",
"File name cannot be empty." => "Filnavnet kan ikke stå tomt.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Ugyldigt navn, '\\', '/', '<', '>', ':' | '?', '\"', '', og '*' er ikke tilladt.",
"Align Left" => "Venstrejusteret",
"Alignment" => "Justering",
"Align Right" => "Højrejusteret",
"Annotate" => "Kommenter",
"Background" => "Baggrund",
"Bold" => "Fed",
"Bottom" => "Bund",
"Cancel" => "Annuller",
"Center" => "Midten",
"Clone" => "Kopier",
"Clone this Style" => "Kopier denne typografi",
"Close" => "Luk",
"Color" => "Farve",
"Create" => "Ny",
"Decrease Indent" => "Formindsk indrykning",
"Default Style" => "Standardtypografi",
"Delete" => "Slet",
"Family" => "Familie",
"Font" => "Skrifttype",
"Font Effects" => "Skifteffekter",
"Format" => "Format",
"Increase Indent" => "Forøg indrykning",
"Insert Image" => "Indsæt billede",
"Invite Members" => "Inviter medlemmer",
"Italic" => "Kursiv",
"Justified" => "Justeret",
"Justify" => "Juster",
"Left" => "Venstre",
"Loading" => "Indlæser",
"Members" => "Medlemmer",
"New Name:" => "Nyt navn:",
"OK" => "OK",
"Open" => "Åbn",
"Options" => "Valgmuligheder",
"Paragraph..." => "Afsnit...",
"Paragraph Styles" => "Afsnitstypografi",
"Redo" => "Gentag",
"Right" => "Højre",
"Size" => "Størrelse",
"Spacing" => "Afstand",
"Strikethrough" => "Gennemstreget",
"Style" => "Typografi",
"Text" => "SMS",
"Top" => "Top",
"Underline" => "Understregning",
"Undo" => "Fortryd",
"Unknown Author" => "Ukendt forfatter",
"Edit" => "Rediger",
"Share" => "Del",
"guest" => "Gæst",
"MS Word support (requires openOffice/libreOffice)" => "MS Word-understøttelse (kræver openOffice/libreOffice)",
"Local" => "Lokal",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice er installeret på denne server. Stien til den binære fil er angivet via preview_libreoffice_path i config.php",
"External" => "Ekstern",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice er installeret på en ekstern server som kører en formatfilter-server",
"Disabled" => "Deaktiveret",
"No MS Word support" => "Ingen understøttelse af MS Word",
"scheme://domain.tld[:port]" => "system://domain.tld[:port]",
"Server URL" => "Server URL",
"Apply and test" => "Anvend og test",
"New document" => "Nyt dokument",
"Upload (max. %s)" => "Upload (max. %s)",
"Upload" => "Upload",
"Save new documents to" => "Gem nye dokumenter til",
"Wrong password. Please retry." => "Forkert kodeord. Prøv igen.",
"Password" => "Kodeord",
"Guest %s" => "Gæst %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Dette link er uløbet eller har aldrig eksisteret. Kontakt venligst personen der delte linket for yderligere detaljer. ",
"Advanced feature-set" => "Avancerede funktioner",
"(Unstable)" => "(Ustabil)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud-app-documents-1%3A0.13.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/da.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Dokumenter",
"Can't create document" => "Kan ikke oprette dokument",
"You don't have permission to rename this document" => "Du har ikke tilladelse til at omdøbe dette dokument",
"Directory saved successfully." => "Mappen blev gemt.",
"An error occurred while changing directory." => "Fejl ved skift af bibliotek.",
"Saved" => "Gemt",
"Format filter server is down or misconfigured" => "Formatfilter-server er nede eller konfigureret forkert",
"Conversion failed. Check log for details." => "Konvertering mislykkedes. Tjek loggen for detaljer.",
"Saving..." => "Gemmer...",
"Failed to load documents." => "Kunne ikke hente dokumenterne. ",
"No documents were found. Upload or create a document to get started!" => "Der blev ikke fundet nogle dokumenter. Upload eller opret et dokument for at komme igang",
"No connection to server. Trying to reconnect." => "Ingen forbindelse til servver. Prøv at forbinde igen.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "At forlade denne side i redigeringstilstand kan resultere i ikke gemte data. Det anbefales at bruge 'Luk' knappen i stedet.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Kunne ikke hentet dette dokument. Undersøg venligst om det kan åbnes med en ekstern odt læser. Dette kan også betyde at dokumentet for nylig er blevet gjort privat eller slettet. ",
"Save" => "Gem",
"Loading documents..." => "Henter dokumenter...",
"'.' is an invalid file name." => "'.' er et ugyldigt filnavn.",
"File name cannot be empty." => "Filnavnet kan ikke stå tomt.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Ugyldigt navn, '\\', '/', '<', '>', ':' | '?', '\"', '', og '*' er ikke tilladt.",
"Align Left" => "Venstrejusteret",
"Alignment" => "Justering",
"Align Right" => "Højrejusteret",
"Annotate" => "Kommenter",
"Background" => "Baggrund",
"Bold" => "Fed",
"Bottom" => "Bund",
"Cancel" => "Annuller",
"Center" => "Midten",
"Clone" => "Kopier",
"Clone this Style" => "Kopier denne typografi",
"Close" => "Luk",
"Color" => "Farve",
"Create" => "Ny",
"Decrease Indent" => "Formindsk indrykning",
"Default Style" => "Standardtypografi",
"Delete" => "Slet",
"Family" => "Familie",
"Font" => "Skrifttype",
"Font Effects" => "Skifteffekter",
"Format" => "Format",
"Increase Indent" => "Forøg indrykning",
"Insert Image" => "Indsæt billede",
"Invite Members" => "Inviter medlemmer",
"Italic" => "Kursiv",
"Justified" => "Justeret",
"Justify" => "Juster",
"Left" => "Venstre",
"Loading" => "Indlæser",
"Members" => "Medlemmer",
"New Name:" => "Nyt navn:",
"OK" => "OK",
"Open" => "Åbn",
"Options" => "Valgmuligheder",
"Paragraph..." => "Afsnit...",
"Paragraph Styles" => "Afsnitstypografi",
"Redo" => "Gentag",
"Right" => "Højre",
"Size" => "Størrelse",
"Spacing" => "Afstand",
"Strikethrough" => "Gennemstreget",
"Style" => "Typografi",
"Text" => "SMS",
"Top" => "Top",
"Underline" => "Understregning",
"Undo" => "Fortryd",
"Unknown Author" => "Ukendt forfatter",
"Shared" => "Delt",
"Error" => "Fejl",
"Error while sharing" => "Fejl under deling",
"Error while unsharing" => "Fejl under annullering af deling",
"Error while changing permissions" => "Fejl under justering af rettigheder",
"Shared with you and the group {group} by {owner}" => "Delt med dig og gruppen {group} af {owner}",
"Shared with you by {owner}" => "Delt med dig af {owner}",
"Share with users or groups …" => "Del med brugere eller grupper",
"Share with users, groups or remote users …" => "Del med brugere, grupper eller eksterne brugere...",
"Share" => "Del",
"Share with people on other ownClouds using the syntax username@example.com/owncloud" => "Del med andre på ownCloud ved hjælp af syntaxen username@example.com/owncloud",
"Share link" => "Del link",
"The public link will expire no later than {days} days after it is created" => "Det offentlige link udløber senest {days} dage efter det blev oprettet",
"Link" => "Link",
"Password protect" => "Beskyt med adgangskode",
"Password" => "Kodeord",
"Choose a password for the public link" => "Vælg et kodeord til det offentlige link",
"Allow editing" => "Tillad redigering",
"Email link to person" => "E-mail link til person",
"Send" => "Send",
"Set expiration date" => "Vælg udløbsdato",
"Expiration" => "Udløb",
"Expiration date" => "Udløbsdato",
"An error occured. Please try again" => "Der skete en fejl. Prøv venligst igen",
"Adding user..." => "Tilføjer bruger...",
"group" => "gruppe",
"remote" => "ekstern",
"Resharing is not allowed" => "Videredeling ikke tilladt",
"Shared in {item} with {user}" => "Delt i {item} med {user}",
"Unshare" => "Fjern deling",
"notify by email" => "Giv besked med mail",
"can share" => "kan dele",
"can edit" => "kan redigere",
"access control" => "Adgangskontrol",
"create" => "opret",
"change" => "tilpas",
"delete" => "slet",
"Password protected" => "Beskyttet med adgangskode",
"Error unsetting expiration date" => "Fejl ved fjernelse af udløbsdato",
"Error setting expiration date" => "Fejl under sætning af udløbsdato",
"Sending ..." => "Sender ...",
"Email sent" => "E-mail afsendt",
"Warning" => "Advarsel",
"Edit" => "Rediger",
"guest" => "Gæst",
"MS Word support (requires openOffice/libreOffice)" => "MS Word-understøttelse (kræver openOffice/libreOffice)",
"Local" => "Lokal",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice er installeret på denne server. Stien til den binære fil er angivet via preview_libreoffice_path i config.php",
"External" => "Ekstern",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice er installeret på en ekstern server som kører en formatfilter-server",
"Disabled" => "Deaktiveret",
"No MS Word support" => "Ingen understøttelse af MS Word",
"scheme://domain.tld[:port]" => "system://domain.tld[:port]",
"Server URL" => "Server URL",
"Apply and test" => "Anvend og test",
"New document" => "Nyt dokument",
"Upload (max. %s)" => "Upload (max. %s)",
"Upload" => "Upload",
"Save new documents to" => "Gem nye dokumenter til",
"Wrong password. Please retry." => "Forkert kodeord. Prøv igen.",
"Guest %s" => "Gæst %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Dette link er uløbet eller har aldrig eksisteret. Kontakt venligst personen der delte linket for yderligere detaljer. ",
"Advanced feature-set" => "Avancerede funktioner",
"(Unstable)" => "(Ustabil)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
